declare @first_date date = '2021-01-01';
declare @last_date date = '2021-06-10 23:59:59';

with aktive_skuffesager as(
	select distinct
		ardk.Id [MglerguideID]
		,ardk.Name [Mgler]
		,de.ID [SkuffesagID]
		,bt.BoligType [Boligtype]
		,de.Gade [Adresse]
		,de.Postnr [Postnr.]
		,case when k.navn is null then '-' else k.navn end [Kommune]
		,CAST(de.Oprettet as date) [Skuffesag oprettet]
		,case when ps.salg_id is not null and (b.Oprettet > ps.omregnings_dato or b.ID is null) then '1 - Solgt som skuffesag'
			else case when b.ID is not null then '3 - Offentligt udbudt'
			else 'Formodet solgt som skuffesag' end end [Kategori]
		--,CAST(b.Oprettet as date) [Annonce oprettet]
		--,CAST(ps.omregnings_dato as date) [Skuffesag solgt]
		,de.ID [SkuffesagsID]
		,b.ID [AnnonceID]
		,ps.salg_id [SalgsID]
	from
		DiscreteEstate de
		inner join AgentRegDK ardk on ardk.Id = de.AgentID
		inner join AgentPremiumBillingLog apbl on apbl.AgentRegId = ardk.Id
		cross apply (
			select top 1 Id
			from 
				PercolateMatches pm 
			where 
				pm.Emailed = 1
				and pm.DiscreteEstateId = de.ID
			) pm
		left join Bolig b on b.EnhedID = de.EnhedID and b.lastchange > de.Oprettet and (b.Status is null or b.Status = 0)
		--left join Bolig b on b.EnhedID = de.EnhedID and b.Oprettet >= de.Oprettet and (b.Status is null or b.Status = 0)
		left join PropertyDataV3 pd on pd.Enhed_id = de.EnhedID and pd.Kommune_Nr = de.KOMMUNE_NR and (pd.HideSales is null or pd.HideSales = 0)
		left join PropertyDataV3Sales ps on ps.ejd_nr = pd.Ejd_Nr and ps.kommune_nr = pd.Kommune_Nr and ps.omregnings_dato >= de.Oprettet
		left join Kommuner k on k.id = de.KOMMUNE_NR
		left join BoligType bt on bt.ID = de.BoligTypeID
	where
		de.Oprettet between @first_date and @last_date
		and de.Oprettet >= apbl.PremiumStartBilling
		and (de.Oprettet <= apbl.PremiumStopBilling or apbl.PremiumStopBilling is null)
		and ardk.Name != 'Test mgler'

), slettede_skuffesager as(
	select distinct
		ardk.Id [MglerguideID]
		,ardk.Name [Mgler]
		,ded.ID [SkuffesagID]
		,bt.BoligType [Boligtype]
		,ded.Gade [Adresse]
		,ded.Postnr [Postnr.]
		,k.navn [Kommune]
		,CAST(ded.Oprettet as date) [Skuffesag oprettet]
		,case when ps.salg_id is not null and (b.Oprettet > ps.omregnings_dato or b.ID is null) then '1 - Solgt som skuffesag'
				else case when b.ID is not null then '3 - Offentligt udbudt'
				else '4 - Er slettet eller skal slettes' end end [Kategori]
		--,CAST(b.Oprettet as date) [Annonce oprettet]
		--,CAST(ps.omregnings_dato as date) [Skuffesag solgt]
		,ded.ID [SkuffesagsID]
		,b.ID [AnnonceID]
		,ps.salg_id [SalgsID]

	from
		DiscreteEstateDeleted ded
		inner join AgentRegDK ardk on ardk.Id = ded.AgentID
		inner join AgentPremiumBillingLog apbl on apbl.AgentRegId = ardk.Id
		cross apply (
			select top 1 Id
			from 
				PercolateMatches pm 
			where 
				pm.Emailed = 1
				and pm.DiscreteEstateId = ded.ID
			) pm
		left join Bolig b on b.EnhedID = ded.EnhedID and b.lastchange > ded.Oprettet and (b.Status is null or b.Status = 0)
		left join PropertyDataV3 pd on pd.Enhed_id = ded.EnhedID and pd.Kommune_Nr = ded.KOMMUNE_NR and (pd.HideSales is null or pd.HideSales = 0)
		left join PropertyDataV3Sales ps on ps.ejd_nr = pd.Ejd_Nr and ps.kommune_nr = pd.Kommune_Nr and ps.omregnings_dato >= ded.Oprettet
		left join Kommuner k on k.id = ded.KOMMUNE_NR
		left join BoligType bt on bt.ID = ded.BoligTypeID

	where
		ded.Oprettet between @first_date and @last_date
		and ded.Oprettet >= apbl.PremiumStartBilling
		and (ded.Oprettet <= apbl.PremiumStopBilling or apbl.PremiumStopBilling is null)
		and ardk.Name != 'Test mgler'

), alle as(
	select distinct
		case when a.MglerguideID is null then s.MglerguideID else a.MglerguideID end [MglerguideID]
		,case when a.Mgler is null then s.Mgler else a.Mgler end [Mgler]
		,case when a.SkuffesagID is null then s.SkuffesagID else a.SkuffesagID end [SkuffesagID]
		,case when a.Boligtype is null then s.Boligtype else a.Boligtype end [Boligtype]
		,case when a.Adresse is null then s.Adresse else a.Adresse end [Adresse]
		,case when a.[Postnr.] is null then s.[Postnr.] else a.[Postnr.] end [Postnr.]
		,case when a.Kommune is null then s.Kommune else a.Kommune end [Kommune]
		,case when a.[Skuffesag oprettet] is null then s.[Skuffesag oprettet] else a.[Skuffesag oprettet] end [Skuffesag oprettet]
		,case when a.Kategori is null then s.Kategori else a.Kategori end [Kategori]
		--,case when a.[Skuffesag solgt] is null then s.[Skuffesag solgt] else a.[Skuffesag solgt] end [Skuffesag solgt]
		,ROW_NUMBER () OVER (partition by 
			case when a.MglerguideID is null then s.MglerguideID else a.MglerguideID end
			,case when a.Mgler is null then s.Mgler else a.Mgler end
			,case when a.Boligtype is null then s.Boligtype else a.Boligtype end
			,case when a.Adresse is null then s.Adresse else a.Adresse end
			,case when a.[Postnr.] is null then s.[Postnr.] else a.[Postnr.] end
			,case when a.AnnonceID is null then s.AnnonceID else a.AnnonceID end
			,case when a.SalgsID is null then s.SalgsID else a.SalgsID end
			order by 
				case when a.SkuffesagsID is null then s.SkuffesagsID else a.SkuffesagsID end) [rn]
	from
		aktive_skuffesager a
		full outer join slettede_skuffesager s on s.SkuffesagID = a.SkuffesagID
)

select
	MglerguideID
	,Mgler
	,SkuffesagID
	,Boligtype
	,Adresse
	,[Postnr.]
	,Kommune
	,[Skuffesag oprettet]
	,Kategori
from 
	alle 
where 
	rn = 1
order by 
	Mgler COLLATE Danish_Norwegian_CI_AS
	,[Skuffesag oprettet]
